<?php
/**
 * About page of Tastybite Theme
 *
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Tastybite_About' ) ) :

class Tastybite_About {

	/**
	 * Constructor.
	 */
	public function __construct() {
		add_action( 'admin_menu', array( $this, 'admin_menu' ) );
		add_action( 'wp_loaded', array( __CLASS__, 'hide_notices' ) );
		add_action( 'load-themes.php', array( $this, 'admin_notice' ) );
	}

	/**
	 * Add admin menu.
	 */
	public function admin_menu() {
		$theme = wp_get_theme( get_template() );

		$page = add_theme_page( esc_html__( 'About', 'tastybite' ) . ' ' . $theme->display( 'Name' ), esc_html__( 'About', 'tastybite' ) . ' ' . $theme->display( 'Name' ), 'activate_plugins', 'tastybite-welcome', array( $this, 'welcome_screen' ) );
		add_action( 'admin_print_styles-' . $page, array( $this, 'enqueue_styles' ) );
	}

	/**
	 * Enqueue styles.
	 */
	public function enqueue_styles() {
		global $tastybite_version;

		wp_enqueue_style( 'tastybite-about-theme', get_template_directory_uri() . '/lib/about-theme/about.css', array(), $tastybite_version );
	}

	/**
	 * Add admin notice.
	 */
	public function admin_notice() {
		global $tastybite_version, $pagenow;

		// Let's bail on theme activation.
		if ( 'themes.php' == $pagenow && isset( $_GET['activated'] ) ) {
			add_action( 'admin_notices', array( $this, 'welcome_notice' ) );
			update_option( 'tastybite_admin_notice_welcome', 1 );

		// No option? Let run the notice wizard again..
		} elseif( ! get_option( 'tastybite_admin_notice_welcome' ) ) {
			add_action( 'admin_notices', array( $this, 'welcome_notice' ) );
		}
	}

	/**
	 * Hide a notice if the GET variable is set.
	 */
	public static function hide_notices() {
		if ( isset( $_GET['tastybite-hide-notice'] ) && isset( $_GET['_tastybite_notice_nonce'] ) ) {
			if ( ! wp_verify_nonce( $_GET['_tastybite_notice_nonce'], 'tastybite_hide_notices_nonce' ) ) {
				wp_die( __( 'Action failed. Please refresh the page and retry.', 'tastybite' ) );
			}

			if ( ! current_user_can( 'manage_options' ) ) {
				wp_die( __( 'Cheat in &#8217; huh?', 'tastybite' ) );
			}

			$hide_notice = sanitize_text_field( $_GET['tastybite-hide-notice'] );
			update_option( 'tastybite_admin_notice_' . $hide_notice, 1 );
		}
	}

	/**
	 * Show welcome notice.
	 */
	public function welcome_notice() {
		?>
		<div class="updated notice is-dismissible construction-zone-notice">
			<h1>Thanks for install Tastybite , Welcome!!			</h1>
			<p>Thank you for choosing Tastybite WordPress theme. To take full advantage of the features this theme has to offer visit our <a href="http://localhost/test/wp-admin/themes.php?page=tastybite_upgrade"> welcome page </a>.</p>
			<p><a href="http://localhost/test/wp-admin/themes.php?page=tastybite-welcome" class="button button-blue-secondary button_info" style="text-decoration: none;">Get started</a></p>
		<button type="button" class="notice-dismiss"><span class="screen-reader-text">Dismiss this notice.</span></button></div>
		<?php
	}

	/**
	 * Intro text/links shown to all about pages.
	 *
	 * @access private
	 */
	private function intro() {
		global $tastybite_version;
		$theme = wp_get_theme( get_template() );

		$theme_name = $theme->get( 'Name' );
		$theme_description = $theme->get( 'Description' );
		$theme_uri = $theme->get( 'ThemeURI' );

		// Drop minor version if 0
		//$major_version = substr( $tastybite_version, 0, 3 );
		?>
		<div class="scholarship-theme-info">

				<h1> <?php echo esc_html( 'About ', 'tastybite' ).' '. esc_html( $theme_name ).' '.esc_html( $tastybite_version ); ?> </h1>

			<div class="welcome-description-wrap">
				<div class="about-text"><?php echo wp_kses_post( $theme_description ); ?></div>

				<div class="scholarship-screenshot">
					<img src="<?php echo esc_url( get_template_directory_uri() ) . '/screenshot.png'; ?>" />
				</div>
			</div>
		</div>

		<p class="scholarship-actions">
			<a href="<?php echo esc_url( $theme_uri ); ?>" class="button button-secondary" target="_blank"><?php esc_html_e( 'Theme Info', 'tastybite' ); ?></a>

			<a href="<?php echo esc_url( apply_filters( 'tastybite_pro_theme_url', 'http://operationwp.com/tastybite-free/' ) ); ?>" class="button button-secondary docs" target="_blank"><?php esc_html_e( 'View Demo', 'tastybite' ); ?></a>

			<a href="<?php echo esc_url( apply_filters( 'tastybite_pro_theme_url', 'http://operationwp.com/themes/testybite-pro/' ) ); ?>" class="button button-primary docs" target="_blank"><?php esc_html_e( 'View PRO version', 'tastybite' ); ?></a>

			<a href="<?php echo esc_url( apply_filters( 'tastybite_pro_theme_url', 'https://wordpress.org/support/theme/tastybite/reviews/?filter=5' ) ); ?>" class="button button-secondary docs" target="_blank"><?php esc_html_e( 'Rate this theme', 'tastybite' ); ?></a>
		</p>

		<h2 class="nav-tab-wrapper">
			<a class="nav-tab <?php if ( empty( $_GET['tab'] ) && $_GET['page'] == 'tastybite-welcome' ) echo 'nav-tab-active'; ?>" href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'tastybite-welcome' ), 'themes.php' ) ) ); ?>">
				<?php echo $theme->display( 'Name' ); ?>
			</a>
			
			<a class="nav-tab <?php if ( isset( $_GET['tab'] ) && $_GET['tab'] == 'free_vs_pro' ) echo 'nav-tab-active'; ?>" href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'tastybite-welcome', 'tab' => 'free_vs_pro' ), 'themes.php' ) ) ); ?>">
				<?php esc_html_e( 'Free Vs Pro', 'tastybite' ); ?>
			</a>

			
			<a class="nav-tab <?php if ( isset( $_GET['tab'] ) && $_GET['tab'] == 'changelog' ) echo 'nav-tab-active'; ?>" href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'tastybite-welcome', 'tab' => 'changelog' ), 'themes.php' ) ) ); ?>">
				<?php esc_html_e( 'Changelog', 'tastybite' ); ?>
			</a>
		</h2>
		<?php
	}

	/**
	 * Welcome screen page.
	 */
	public function welcome_screen() {
		$current_tab = empty( $_GET['tab'] ) ? 'about' : sanitize_title( $_GET['tab'] );

		// Look for a {$current_tab}_screen method.
		if ( is_callable( array( $this, $current_tab . '_screen' ) ) ) {
			return $this->{ $current_tab . '_screen' }();
		}

		// Fallback to about screen.
		return $this->about_screen();
	}

	/**
	 * Output the about screen.
	 */
	public function about_screen() {
		$theme = wp_get_theme( get_template() );

		$theme_name = $theme->get( 'Name' );
		$theme_description = $theme->get( 'Description' );
		$theme_uri = $theme->get( 'ThemeURI' );
	?>
		<div class="wrap about-wrap">

			<?php $this->intro(); ?>

			<div class="changelog point-releases">
				<div class="under-the-hood two-col">
					<div class="col">
						<h3><?php esc_html_e( 'Theme Customizer', 'tastybite' ); ?></h3>
						<p><?php esc_html_e( 'All Theme Options are available via Customize screen.', 'tastybite' ) ?></p>
						<p><a href="<?php echo admin_url( 'customize.php' ); ?>" class="button button-secondary"><?php esc_html_e( 'Customize', 'tastybite' ); ?></a></p>
					</div>

					<div class="col">
						<h3><?php esc_html_e( 'Documentation', 'tastybite' ); ?></h3>
						<p><?php esc_html_e( 'Please view our documentation page to setup the theme.', 'tastybite' ) ?></p>
						<p><a href="<?php echo esc_url( 'http://operationwp.com/doc/tastybite/index.html' ); ?>" class="button button-secondary" target="_blank"><?php esc_html_e( 'Documentation', 'tastybite' ); ?></a></p>
					</div>

					<div class="col">
						<h3><?php esc_html_e( 'Got theme support question?', 'tastybite' ); ?></h3>
						<p><?php esc_html_e( 'Please put it in our dedicated support forum.', 'tastybite' ) ?></p>
						<p><a href="<?php echo esc_url( 'https://wordpress.org/support/theme/tastybite' ); ?>" class="button button-secondary" target="_blank"><?php esc_html_e( 'Support', 'tastybite' ); ?></a></p>
					</div>

					<div class="col">
						<h3><?php esc_html_e( 'Need more features?', 'tastybite' ); ?></h3>
						<p><?php esc_html_e( 'Upgrade to PRO version for more exciting features.', 'tastybite' ) ?></p>
						<p><a href="<?php echo esc_url( 'http://operationwp.com/themes/testybite-pro/' ); ?>" class="button button-secondary" target="_blank"><?php esc_html_e( 'View PRO version', 'tastybite' ); ?></a></p>
					</div>

					<div class="col">
						<h3><?php esc_html_e( 'Have you need customization?', 'tastybite' ); ?></h3>
						<p><?php esc_html_e( 'Please send message with your requirement.', 'tastybite' ) ?></p>
						<p><a href="<?php echo esc_url( 'http://operationwp.com/themes/testybite-pro' ); ?>" class="button button-secondary" target="_blank"><?php esc_html_e( 'Customization', 'tastybite' ); ?></a></p>
					</div>

					<div class="col">
						<h3> <?php echo esc_html( 'Translate', 'tastybite' ).' '.esc_html( $theme_name ); ?> </h3>
						<p><?php esc_html_e( 'Click below to translate this theme into your own language.', 'tastybite' ) ?></p>
						<p>
							<a href="<?php echo esc_url( 'https://translate.wordpress.org/projects/wp-themes/tastybite' ); ?>" class="button button-secondary" target="_blank"><?php echo esc_html( 'Translate', 'tastybite' ).' '.esc_html( $theme_name ); ?></a>
						</p>
					</div>
				</div>
			</div><!-- .point-releases -->

			<div class="return-to-dashboard scholarship">
				<?php if ( current_user_can( 'update_core' ) && isset( $_GET['updated'] ) ) : ?>
					<a href="<?php echo esc_url( self_admin_url( 'update-core.php' ) ); ?>">
						<?php is_multisite() ? esc_html_e( 'Return to Updates', 'tastybite' ) : esc_html_e( 'Return to Dashboard &rarr; Updates', 'tastybite' ); ?>
					</a> |
				<?php endif; ?>
				<a href="<?php echo esc_url( self_admin_url() ); ?>"><?php is_blog_admin() ? esc_html_e( 'Go to Dashboard &rarr; Home', 'tastybite' ) : esc_html_e( 'Go to Dashboard', 'tastybite' ); ?></a>
			</div><!-- .return-to-dashboard -->
		</div><!-- .about-wrap -->
	<?php
	}

	

	/** 
	 * Get all our themes by using API.
	 */
	private function tastybite_get_themes( $request ) {

		// Generate a cache key that would hold the response for this request:
		$key = 'tastybite_' . md5( serialize( $request ) );

		// Check transient. If it's there - use that, if not re fetch the theme
		if ( false === ( $themes = get_transient( $key ) ) ) {

			// Transient expired/does not exist. Send request to the API.
			$response = wp_remote_post( 'http://api.wordpress.org/themes/info/1.0/', $request );

			// Check for the error.
			if ( !is_wp_error( $response ) ) {

				$themes = unserialize( wp_remote_retrieve_body( $response ) );

				if ( !is_object( $themes ) && !is_array( $themes ) ) {

					// Response body does not contain an object/array
					return new WP_Error( 'theme_api_error', 'An unexpected error has occurred' );
				}

				// Set transient for next time... keep it for 24 hours should be good
				set_transient( $key, $themes, 60 * 60 * 24 );
			}
			else {
				// Error object returned
				return $response;
			}
		}
		return $themes;
	}
	
	/**
	 * Output the changelog screen.
	 */
	public function changelog_screen() {
		global $wp_filesystem;

	?>
		<div class="wrap about-wrap">

			<?php $this->intro(); ?>

			<h4><?php esc_html_e( 'View changelog below:', 'tastybite' ); ?></h4>

			<?php
				$changelog_file = apply_filters( 'tastybite_changelog_file', get_template_directory() . '/readme.txt' );

				// Check if the changelog file exists and is readable.
				if ( $changelog_file && is_readable( $changelog_file ) ) {
					WP_Filesystem();
					$changelog = $wp_filesystem->get_contents( $changelog_file );
					$changelog_list = $this->parse_changelog( $changelog );

					echo wp_kses_post( $changelog_list );
				}
			?>
		</div>
	<?php
	}

	/**
	 * Parse changelog from readme file.
	 * @param  string $content
	 * @return string
	 */
	private function parse_changelog( $content ) {
		$matches   = null;
		$regexp    = '~==\s*Changelog\s*==(.*)($)~Uis';
		$changelog = '';

		if ( preg_match( $regexp, $content, $matches ) ) {
			$changes = explode( '\r\n', trim( $matches[1] ) );

			$changelog .= '<pre class="changelog">';

			foreach ( $changes as $index => $line ) {
				$changelog .= wp_kses_post( preg_replace( '~(=\s*Version\s*(\d+(?:\.\d+)+)\s*=|$)~Uis', '<span class="title">${1}</span>', $line ) );
			}

			$changelog .= '</pre>';
		}

		return wp_kses_post( $changelog );
	}

	/**
	 * Output the free vs pro screen.
	 */
	public function free_vs_pro_screen() {
		?>
		<div class="wrap about-wrap">

			<?php $this->intro(); ?>

			<h4><?php esc_html_e( 'Upgrade to PRO version for more exciting features.', 'tastybite' ); ?></h4>

			<table>
				<thead>
					<tr>
						<th class="table-feature-title"><h3><?php esc_html_e( 'Features', 'tastybite' ); ?></h3></th>
						<th><h3><?php esc_html_e( 'Tastybite', 'tastybite' ); ?></h3></th>
						<th><h3><?php esc_html_e( 'Tastybite Pro', 'tastybite' ); ?></h3></th>
					</tr>
				</thead>
				<tbody>
					<tr>
						<td><h3><?php esc_html_e( 'Price', 'tastybite' ); ?></h3></td>
						<td><?php esc_html_e( 'Free', 'tastybite' ); ?></td>
						<td><?php esc_html_e( '$55', 'tastybite' ); ?></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e( 'Import Demo Data', 'tastybite' ); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e( 'Pre Loaders', 'tastybite' ); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e( 'Header Layouts', 'tastybite' ); ?></h3></td>
						<td><?php esc_html_e( '1', 'tastybite' ); ?></td>
						<td><?php esc_html_e( '3', 'tastybite' ); ?></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e( 'Archive Pages Layouts', 'tastybite' ); ?></h3></td>
						<td><?php esc_html_e( '1', 'tastybite' ); ?></td>
						<td><?php esc_html_e( '3', 'tastybite' ); ?></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e( 'Single Page Layouts', 'tastybite' ); ?></h3></td>
						<td><?php esc_html_e( '1', 'tastybite' ); ?></td>
						<td><?php esc_html_e( '3', 'tastybite' ); ?></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e( 'Google Fonts', 'tastybite' ); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><?php esc_html_e( '600+', 'tastybite' ); ?></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e( 'Typography Options', 'tastybite' ); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e( 'Premium Widgets', 'tastybite' ); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e( 'The Events Calendar Plugin Compatible', 'tastybite' ); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e( 'Custom 404 Page', 'tastybite' ); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e( 'Animation on Section', 'tastybite' ); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e( 'Food Menu Detail', 'tastybite' ); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e( 'Unlimited Color Scheme', 'tastybite' ); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e( 'Slider Option', 'tastybite' ); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e( 'Bottom Footer Layouts', 'tastybite' ); ?></h3></td>
						<td><?php esc_html_e( '1', 'tastybite' ); ?></td>
						<td><?php esc_html_e( '2', 'tastybite' ); ?></td>
					</tr>										
					<tr>
						<td></td>
						<td></td>
						<td class="btn-wrapper">
							<a href="<?php echo esc_url( apply_filters( 'tastybite_pro_theme_url', 'http://operationwp.com/themes/testybite-pro/' ) ); ?>" class="button button-secondary docs" target="_blank"><?php esc_html_e( 'View Pro', 'tastybite' ); ?></a>
						</td>
					</tr>
				</tbody>
			</table>

		</div>
		<?php
	}
}

endif;

return new Tastybite_About();